import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { findVitestDeps } from '../vitest/index.js';
export const NAME = 'Vite';
export const ENABLERS = ['vite'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['vite.config.{js,ts}'];
const findViteDependencies = async (configFilePath, options) => {
    const localConfig = await load(configFilePath);
    if (!localConfig)
        return [];
    if (typeof localConfig === 'function') {
        const dependencies = new Set();
        for (const command of ['dev', 'serve', 'build']) {
            for (const mode of ['development', 'production']) {
                const config = await localConfig({ command, mode, ssrBuild: undefined });
                findVitestDeps(config, options).forEach(dependency => dependencies.add(dependency));
            }
        }
        return Array.from(dependencies);
    }
    return findVitestDeps(localConfig, options);
};
export const findDependencies = timerify(findViteDependencies);
